@@ -50,7 +50,7 @@
 + (HKSyntaxDefinition *) syntaxDefinitionForType: (NSString *) type;
 + (void) themeDidChange;
 
-- initWithContextList: (NSArray *) contexts;
+- (id) initWithContextList: (NSArray *) contexts;
 
 // Obtaining context starting, ending and skips
 - (HKTextPattern **) contextBeginnings;
